/*
 * Volleyball - video game similary to GNU Arcade Volleyball
 * Copyright (C) 2005, 2006 Hugo Ruscitti : hugoruscitti@gmail.com
 * web site: http://www.loosersjuegos.com.ar
 * 
 * This file is part of Volleyball.
 *
 * Volleyball is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Volleyball is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 */

#include "about.h"
#include "control.h"
#include "main_menu.h"
#include "font.h"

/*!
 * \brief inicia la escena `Acerca de ...`
 * \param world mdulo world
 * \return el mdulo creado
 */
About * about_init (World * world)
{
	About * data;

	data = (About *) malloc (sizeof (About));

	if (! data)
	{
		util_print_fail_module ("About");
		exit (1);
	}

	data->world = world;

	data->memo = memo_init (world, _(
				"About Pocket Volleyball\n"
				"\n"
				"Programming:\n"
				" + Hugo Ruscitti\n"
				" + Gabriel Valentin\n"
				" + Nicolas Adenis-Lamarre\n"
				"\n"
				"Graphics:\n"
				" + Walter Velazquez"));
			
	about_draw_background (data);

	return data;
}


/*!
 * \brief Imprime el fondo de la pantalla
 * \param data mdulo principal
 */
void about_draw_background (About * data)
{
	SDL_Surface * background;

	background = util_load_image (DATADIR "/about.png", FALSE);

	if (background)
	{
		display_set_background (data->world->display, background);
		SDL_FreeSurface (background);
	}
}


/*!
 * \brief actualiza la escena
 * \param data mdulo principal
 */
void about_update (About * data)
{
	memo_update (data->memo);

	if (control_query (data->world->control, QUIT))
	{
		Main_menu * menu;

		menu = main_menu_init (data->world, 3);
	
		world_change_scene (data->world, menu, main_menu_update, 
				main_menu_draw, main_menu_free);
	}
}

/*!
 * \brief imprime la escena
 * \param data mdulo principal
 */
void about_draw (About * data)
{
	Font * font = data->world->font;
	Display * display = data->world->display;

	memo_draw (data->memo);
	
	font_printf (font, display, 80, 430, TYPE_SELECTED, 
			_("Press ESCAPE to continue"));
}

/*!
 * \brief libera la escena
 * \param data mdulo principal
 */
void about_free (About * data)
{
	memo_free (data->memo);
	free (data);
}
