/*
 * Volleyball - video game similary to GNU Arcade Volleyball
 * Copyright (C) 2005, 2006 Hugo Ruscitti : hugoruscitti@gmail.com
 * web site: http://www.losersjuegos.com.ar
 * 
 * This file is part of Volleyball.
 *
 * Volleyball is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Volleyball is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 */

#include "animation.h"

/*!
 * \brief Inicia un mdulo de animacin
 * \param default_delay demora en avanzar de cuadros
 * \return el mdulo creado
 */
Animation * animation_init (int default_delay)
{
	Animation * data;
	int i;
	
	data = (Animation *) malloc (sizeof (Animation));
	
	if (data == NULL)
	{
		util_print_fail_module ("Animation");
		exit (1);
	}

	data->default_delay = default_delay;

	for (i = 0; i < _MAX_ANIMATION_TYPE; i ++)
	{
		data->frames [i] [0] = 0;
		data->frames [i] [1] = -1;
	}

	return data;
}


/*!
 * \brief Aade una nueva secuencia de cuadros
 * \param data mdulo principal
 * \param type indentificardor de la animacin
 * \param frames cuadros de animacin en formato cadena
 */
void animation_add (Animation * data, enum animation_type type, char frames [])
{
	int i = 0;
	char buffer [1024];
	char * value;

	strcpy (buffer, frames);

	value = strtok (buffer, " ");

	while (value)
	{
		data->frames [type] [i] = atoi (value);
		i ++;
		value = strtok (NULL, " ");
	}

	data->frames [type] [i] = -1;
}

/*!
 * \brief Actualizacin lgica
 * \param data mdulo principal
 * \return 1 en caso de haber terminado la animacin, 0 en caso contrario
 */
int animation_update (Animation * data)
{
	int last_frame = (data->frames [data->type] [data->step + 1] == -1);
	
	if (data->delay > 1)
	{
		data->delay --;
		return 0;
	}
	else
	{
		/* intenta avanzar un cuadro */
		data->delay = data->default_delay;
	
		if (last_frame)
		{
			animation_reset (data, data->type);
//			data->step = 0;
//			data->actual_frame = data->frames [data->type] [0];
			return 1;
		}
		else
			data->step ++;

		data->actual_frame = data->frames [data->type] [data->step];
		return 0;
	}
}


/*!
 * \brief Redefine la animacin a mostrar
 * \param data mdulo principal
 * \param type indentificador de la prxima animacin
 */
void animation_reset (Animation * data, enum animation_type type)
{
	data->step = 0;
	data->delay = data->default_delay;
	data->type = type;
	data->actual_frame = data->frames [type] [0];
}


/*!
 * \brief Libera los recursos solicitados
 * \param data mdulo principal
 */
void animation_free (Animation * data)
{
	free (data);
}

/*!
 * \brief Muestra una animacin en particular ver `update` y `reset`
 * \param data mdulo principal
 * \param type identificador de la animacin
 * \return 1 si reinici la animacin
 */
int animation_update_or_reset (Animation * data, enum animation_type type)
{
	if (data->type == type)
		return animation_update (data);
	else
	{
		animation_reset (data, type);
		return 1;
	}
}
