/*
 * Volleyball - video game similary to GNU Arcade Volleyball
 * Copyright (C) 2005, 2006 Hugo Ruscitti : hugoruscitti@gmail.com
 * web site: http://www.losersjuegos.com.ar
 * 
 * This file is part of Volleyball.
 *
 * Volleyball is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Volleyball is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 */

#ifndef _ANIMATION_H
#define _ANIMATION_H

#include "common.h"


/*!
 * \brief Tipo de animacin del personajes
 */
enum animation_type {
	READY,
	RUN_LEFT,
	RUN_RIGHT,
	JUMP,
	IN_SELECT,
	TOUCH_BACK,
	TOUCH_UP,
	TOUCH_FRONT,
	TOUCH_BACK_JUMPING,
	TOUCH_UP_JUMPING,
	TOUCH_FRONT_JUMPING,
	_MAX_ANIMATION_TYPE
};

/*!
 * \brief Representa todos los cuadros de animacin de un estado del personaje
 */
typedef struct animation_t
{
	int frames [_MAX_ANIMATION_TYPE] [MAX_FRAMES_PER_ANIMATION + 1];

	enum animation_type type;
	int step;
	int delay;
	int default_delay;
	int actual_frame;
} Animation;

Animation * animation_init (int default_delay);
void animation_add (Animation * data, enum animation_type type, char frames []);
int animation_update (Animation * data);
void animation_reset (Animation * data, enum animation_type type);
void animation_free (Animation * data);
int animation_update_or_reset (Animation * data, enum animation_type type);

#endif
