/*
 * Volleyball - video game similary to GNU Arcade Volleyball
 * Copyright (C) 2005, 2006 Hugo Ruscitti : hugoruscitti@gmail.com
 * web site: http://www.losersjuegos.com.ar
 * 
 * This file is part of Volleyball.
 *
 * Volleyball is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Volleyball is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 */

#ifndef _AUDIO_H
#define _AUDIO_H

#include "common.h"
#include "SDL_mixer.h"

enum sound_id {
	SND_CHANGE_OPTION,	/*< Cambia un objeto seleccionado en el men */
	SND_SELECT_OPTION,	/*< Selecciona un objeto en el men */
	SND_COLLISION_1,	/*< Golpe del jugador izquierdo */
	SND_COLLISION_2,	/*< Golpe del jugador derecho */
	SND_KO,			/*< Final del partido */
	SND_TOUCH,		/*< Rebote de la pelota */
	_SND_MAX		/*< indica la cantidad de sonidos disponibles */
	};

/*!
 * \brief Gestiona todo lo relacionado con el audio del programa. El
 * mdulo no es indispensable para que el programa funcione, si 
 * la bibliteca SDL_Mixer no puede acceder al controlador de sonido del
 * sistema, el programa continua pero sin soporte de sonido.
 *
 * Cada sonido o msica cuenta con su propio identificador, de esta
 * forma podr llamar a la funcin `audio_play_sound (id_sound)` o 
 * `audio_play_music (id_musica)` para acceder a cada recurso.
 *
 */
typedef struct audio_t
{
	int enabled;			/*< Indica si puede utilizar el audio */
	int sound_volume;		/*< volumen del sonido */
	Mix_Chunk * sounds [_SND_MAX];	/*< Sonidos disponibles */
} Audio;


Audio * audio_init (int enabled);
void audio_load_sounds (Audio * data);
void audio_load_sound (Audio * data, enum sound_id id);
void audio_play_sound (Audio * data, enum sound_id id);
void audio_set_sound_volume (void * data, int volume);
int audio_get_sound_volume (Audio * data);
int audio_is_enabled (Audio * data);
void audio_free (Audio * data);


#endif
