/*
 * Volleyball - video game similary to GNU Arcade Volleyball
 * Copyright (C) 2005, 2006 Hugo Ruscitti : hugoruscitti@gmail.com
 * web site: http://www.loosersjuegos.com.ar
 * 
 * This file is part of Volleyball.
 *
 * Volleyball is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Volleyball is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 */

#ifndef _CHARACTERS_H
#define _CHARACTERS_H

#include "node.h"
#include "player.h"
#include "options.h"

/*!
 * \file
 */

/*!
 * \brief Almacena y gestiona un conjunto completo de personajes
 *
 * Cuando el mdulo se inicia, se examinarn varios directorios del
 * sistema en busca de personajes para el juego. Cabe destacar que
 * cada usuario puede crear sus propios personajes para el videojuego. En
 * la Web del proyecto `Losersjuegos` existe un artculo que lo explica.
 *
 * Los personajes se buscarn, generalmente, en '$HOME/.volleyball/characters'
 * y en 'DATADIR/characters' (DATADIR suele valer '/usr/share/volleyball').
 *
 * El mdulo mantiene la lista de personajes durante toda la ejecucin del
 * programa, `World` se encargar de `iniciar` y `terminar` el mdulo.
 *
 */
typedef struct characters
{
	Node * list;
	Options * options;
} Characters;

Characters * characters_init (Options * options);
int characters_count_players (Characters * data);
void characters_start_scan (Characters * data);
void characters_scan_dir (Characters * data, char * path);
void characters_new_player (Characters * data, char * path, char * file);
void characters_free (Characters * data);
Player * characters_get_player (Characters * data, int index);
Player * characters_get_random_player (Characters * data);

#endif
