/*
 * Volleyball - video game similary to GNU Arcade Volleyball
 * Copyright (C) 2005, 2006 Hugo Ruscitti : hugoruscitti@gmail.com
 * web site: http://www.loosersjuegos.com.ar
 * 
 * This file is part of Volleyball.
 *
 * Volleyball is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Volleyball is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 */

#include "control.h"

/*!
 * \brief inicia el mdulo
 * \return un nuevo mdulo Control
 */
Control * control_init (void)
{
	Control * data;

	data = (Control *) malloc (sizeof (Control));

	if (! data)
	{
		util_print_fail_module ("Control");
		exit (1);
	}


	control_set_key (data, ENTER, SDLK_RETURN);
	control_set_key (data, QUIT, SDLK_ESCAPE);

	control_set_key (data, P1_UP, SDLK_w);
	control_set_key (data, P1_DOWN, SDLK_s);
	control_set_key (data, P1_LEFT, SDLK_a);
	control_set_key (data, P1_RIGHT, SDLK_d);
	control_set_key (data, P1_SELECT, SDLK_1);

	control_set_key (data, P2_UP, SDLK_UP);
	control_set_key (data, P2_DOWN, SDLK_DOWN);
	control_set_key (data, P2_LEFT, SDLK_LEFT);
	control_set_key (data, P2_RIGHT, SDLK_RIGHT);
	control_set_key (data, P2_SELECT, SDLK_RCTRL);

	return data;
}

/*!
 * \brief actualiza el estado de las teclas
 * \param data mdulo principal
 */
void control_update (Control * data)
{
	data->keys = SDL_GetKeyState (NULL);
}

/*!
 * \brief informa si una tecla ha sido pulsada
 * \param data mdulo principal
 * \param key tecla a consultar
 * \return TRUE (1) en caso afirmativo, FALSE (!= 1) en caso contrario
 */
int control_query (Control * data, enum keys key)
{
	if (key == NONE)
		return FALSE;
	else
		return (data->keys [data->custom_keys [key]]);
}

/*!
 * \brief informa si una tecla ha sido pulsada una sola vez
 * \param data mdulo principal
 * \param key tecla a consultar
 * \return TRUE (1) en caso afirmativo, FALSE (!= 1) en caso contrario
 */
int control_query_no_repeat (Control * data, enum keys key)
{
	static enum keys last_key = NONE;

	if (! control_query (data, last_key))
		last_key = NONE;

	if (key != last_key && control_query (data, key))
	{
		last_key = key;
		return 1;
	}
	else
		return 0;
}

/*!
 * \brief permite personalizar las teclas del gestor de controles
 * \param data mdulo principal
 * \param reference_key nombre de recibe la tecla en el juego
 * \param new_key nueva tecla
 */
void control_set_key (Control * data, enum keys reference_key, SDLKey new_key)
{
	data->custom_keys [reference_key] = new_key;
}

/*!
 * \brief libera el mdulo de memoria
 * \param data mdulo principal
 */
void control_free (Control * data)
{
	free (data);
}
