/*
 * Volleyball - video game similary to GNU Arcade Volleyball
 * Copyright (C) 2005, 2006 Hugo Ruscitti : hugoruscitti@gmail.com
 * web site: http://www.loosersjuegos.com.ar
 * 
 * This file is part of Volleyball.
 *
 * Volleyball is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Volleyball is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 */

#ifndef _CONTROL_H
#define _CONTROL_H

#include "common.h"

/*!
 * \brief nombre que reciben las teclas que operan en este juego
 */
enum keys {
	NONE = -1, 	/*! < Valor nulo */
	ENTER,		/*! < acepta una opcin */
	QUIT,		/*! < cancela una opcin o escena */
	P1_UP,		/*! < subir */
	P1_DOWN,	/*! < bajar */
	P1_LEFT,	/*! < izquierda */
	P1_RIGHT,	/*! < derecha */
	P1_SELECT,	/*! < selecciona */
	P2_UP,		/*! < subir */
	P2_DOWN,	/*! < bajar */
	P2_LEFT,	/*! < izquierda */
	P2_RIGHT,	/*! < derecha */
	P2_SELECT,	/*! < selecciona */
	_MAX_KEYS,	/*! < cantidad de constantes */
};



/*!
 * \file
 */

/*!
 * \brief Controlador de teclado, representa las teclas de un jugador
 */
typedef struct control_t
{
	Uint8 * keys;
	enum keys custom_keys [_MAX_KEYS];
} Control;


Control * control_init (void);
void control_update (Control * data);
int control_query (Control * data, enum keys key);
int control_query_no_repeat (Control * data, enum keys key);
void control_set_key (Control * data, enum keys reference_key, SDLKey new_key);
void control_free (Control * data);

#endif
