/*
 * Volleyball - video game similary to GNU Arcade Volleyball
 * Copyright (C) 2005, 2006 Hugo Ruscitti : hugoruscitti@gmail.com
 * web site: http://www.loosersjuegos.com.ar
 * 
 * This file is part of Volleyball.
 *
 * Volleyball is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Volleyball is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 */

#ifndef _CURSOR_H
#define _CURSOR_H

#include "common.h"
#include "util.h"
#include "display.h"
#include "player_control.h"
#include "world.h"

/*!
 * \file
 */

/*!
 * \brief Selector utilizado en la seleccin de personajes (escena `Select`)
 *
 */
typedef struct cursor_t
{
	World * world;			/*!< mdulo principal del juego */
	Player_control * control; 	/*!< controlador de movimiento */
	Player * player;		/*!< jugador seleccionado actualmente */
	SDL_Surface * image;		/*!< superficie principal */
	int x;				/*!< coordenada horizontal */
	int y;			/*!< coordenada vertical */
	int index;		/*!< posicin del cursor [0, max_characters) */
	int player_number;	/*!< indice de jugador (0 o 1) */
	int end_x;		/*!< posicin a la que debe llegar el cursor */
	int end_y;		/*!< posicin a la que debe llegar el cursor */
	int max_characters;	/*!< numero mximo de jugadores disponibles */
	float step;		/*!< avanza como contador y dominio de `sin` */
	int sin_image;		/*!< resultado de evaluar `sin` en `update` */
	int active;		/*!< si no ha seleccionado ningn personaje */
} Cursor;

Cursor * cursor_init (World * world, int player, int max_characters);
void cursor_set_start_position (Cursor * data);
void cursor_move_to (Cursor * data, int character_index);
void cursor_update (Cursor * data);
void cursor_draw (Cursor * data, Display * display);
void cursor_select (Cursor * data);
void cursor_free (Cursor * data);
Player * cursor_get_player (Cursor * data);
void cursor_change_player (Cursor * data);
void cursor_draw_player_nick (Cursor * data, Display * display);
int cursor_selected (Cursor * data);

#endif
