/*
 * Volleyball - video game similary to GNU Arcade Volleyball
 * Copyright (C) 2005, 2006 Hugo Ruscitti : hugoruscitti@gmail.com
 * web site: http://www.loosersjuegos.com.ar
 * 
 * This file is part of Volleyball.
 *
 * Volleyball is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Volleyball is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 */

#include "fileoptions.h"

int file_load (FileOptions * data, int n_data, char * path_to_file)
{
	FILE * file;
	char buffer [1024];

	file = fopen (path_to_file, "rt");

	if (! file)
	{
		printf (_("Can't open '%s' file\n"), path_to_file);
		return 1;
	}

	while (fgets (buffer, 1024, file))
	{
		if (! file_is_comment (buffer))
		{
			if (strstr (buffer, "="))
				file_load_value (data, buffer, n_data);
		}
	}

	fclose (file);

	if (! file_are_complete (data, n_data))
		return 1;

	return 0;
}


/*!
 * \brief Informa si la cadena representa un comentario
 * \param buffer cadena a evaluar
 * \return 1 si es un comentario, 0 en otro caso
 */
int file_is_comment (char * buffer)
{
	int i;

	for (i = 0; buffer [i]; i ++)
	{
		if (isalnum (buffer [i]))
			return 0;

		if (buffer [i] == '#')
			return 1;
	}

	return 1;
}


/*!
 * \brief Carga el valor de una opcin al mdulo
 * \param data mdulo principal
 * \param buffer cadena que contiene el nombre de opcin y el valor
 * \param n_data cantidad de opciones vlidas
 */
void file_load_value (FileOptions * data, char * buffer, int n_data)
{
	char * name;
	char * value;
	int i;
	
	name = buffer;
	value = strstr (buffer, "=") + 1;
	value [-1] = '\0';

	util_remove_breakline (value);
	util_remove_spaces (name);
	util_remove_spaces (value);
	
	for (i = 0; i < n_data; i ++)
	{
		if (strcmp (data [i].name, name) == 0)
		{
			strcpy (data [i].value, value);
			return;
		}
	}

	printf (_("Invalid option: name '%s' value '%s'\n"), name, value);
}


/*!
 * \brief Analiza si el mdulo ha quedado incompleto (falta de valores)
 * \param data mdulo principal
 * \param n_data cantidad de opciones vlidas
 * \return 1 si el mdulo est incompleto, 0 en otro caso
 */
int file_are_complete (FileOptions * data, int n_data)
{
	int i = 0;
	int fault = 0;

	for (i = 0; i < n_data; i ++)
	{
		if (strcmp (data [i].value, "") == 0)
		{
			if (fault == 0)
				printf (_("Error\n"));

			printf ("\t\t");
			printf (_("Can't find '%s' option\n"), data [i].name);
			fault ++;
		}
	}

	if (fault > 0)
	{
		printf ("\t\t");
		printf (_("The options file have some errors\n"));
		return 0;
	}
	else
		return 1;

}


/*!
 * \brief obtiene el valor de una opcin en particular
 * \param data mdulo principal
 * \param n_data cantidad de elementos del mdulo
 * \param name identificador de la opcin 
 * \return un puntero al valor de la opcin o NULL en caso de error
 */
char * file_get_value (FileOptions * data, int n_data, char * name)
{
	int i;

	for (i = 0; i < n_data; i ++)
	{
		if (strcmp (data [i].name, name) == 0)
			return data [i].value;
	}

	printf (_("Can't found '%s' element in options vector\n"), name);
	return NULL;
}

