/*
 * Volleyball - video game similary to GNU Arcade Volleyball
 * Copyright (C) 2005, 2006 Hugo Ruscitti : hugoruscitti@gmail.com
 * web site: http://www.loosersjuegos.com.ar
 * 
 * This file is part of Volleyball.
 *
 * Volleyball is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Volleyball is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 */

#ifndef _FILEOPTIONS_H
#define _FILEOPTIONS_H

/*!
 * \file
 */

#include "common.h"

/*!
 * \brief Gestiona el acceso y consulta a un archivo de configuracin
 *
 * Los archivos de configuracin almacenan conjuntos de atributos identificados
 * bajo un 'nombre' y contienen 'valor'. El archivo es de solo texto, y 
 * puede contener comentarios comenzados por #.
 *
 * Uno de las tareas que facilita este mdulo es el de acceder a los archivos
 * `info.txt` que definen los atributos de un personaje, puede consultar
 * estos archivos buscando en '$DATADIR/characters'.
 *
 * El mdulo completo ser considerado como un vector de FileOptions, en
 * lugar de una unidad, por ese motivo las funciones del mdulo solicitan
 * la cantidad de estructuras-mdulo a operar.
 */
typedef struct fileoptions_t
{
	char name [512];
	char value [1024];
} FileOptions;

int file_load (FileOptions * data, int n_data, char * path_to_file);
int file_is_comment (char * buffer);
void file_load_value (FileOptions * data, char * buffer, int n_data);
int file_are_complete (FileOptions * data, int n_data);
char * file_get_value (FileOptions * data, int n_data, char * name);

#endif
