/*
 * Volleyball - video game similary to GNU Arcade Volleyball
 * Copyright (C) 2005, 2006 Hugo Ruscitti : hugoruscitti@gmail.com
 * web site: http://www.loosersjuegos.com.ar
 * 
 * This file is part of Volleyball.
 *
 * Volleyball is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Volleyball is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 */

#ifndef _FONT_H
#define _FONT_H

#include "common.h"
#include "display.h"

/*!
 * \brief Especifica el tipo de alineacin horizontal de texto
 */
enum align
{
	ALIGN_LEFT,		/*!< Izquierda */
	ALIGN_CENTER,		/*!< Centrado */
	ALIGN_RIGHT		/*!< Derecha */
};


/*!
 * \brief Especifica el tipo de fuente a imprimir
 */
enum type
{
	TYPE_NORMAL,		/*!< fuente normal */
	TYPE_SELECTED,		/*!< fuente seleccionada */
	TYPE_DISABLED		/*!< fuente deshabilitada */	
};

/*!
 * \file
 */

/*!
 * \brief Gestor de fuentes, permite imprimir textos en pantalla
 */
typedef struct font_t
{
	SDL_Surface * image;
	SDL_Surface * image_selected;
	SDL_Surface * image_disabled;
	SDL_Rect rects [150];
} Font;


Font * font_init (char * file, char * file_selected, char * file_disabled);
int font_print_char (Font * data, Display * display, int x, int y, 
		enum type type, char c);
void font_free (Font * data);
int font_get_index (char c);
int font_get_h (Font * data);
void font_scan_rects (Font * data);
int font_is_empty_column (SDL_Surface * ima, int col);
void font_store_rect (SDL_Rect * rect, int x, int y, int w, int h);
void font_printf (Font * data, Display * display, int x, int y, enum type type,
		const char * format, ...);
void font_printf_align (Font * data, Display * display, int x, int y, 
		int selected, enum align align, const char * format, ...);
int font_get_text_width (Font * data, const char * text);
int font_get_char_width (Font * data, char c);

#endif
