/*
 * Volleyball - video game similary to GNU Arcade Volleyball
 * Copyright (C) 2005, 2006 Hugo Ruscitti : hugoruscitti@gmail.com
 * web site: http://www.loosersjuegos.com.ar
 * 
 * This file is part of Volleyball.
 *
 * Volleyball is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Volleyball is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 */

#ifndef _FPS_H
#define _FPS_H

/*!
 * \file
 */

#include "common.h"

/*!
 * \brief Administra la velocidad constante del videojuego
 *
 * Cuando se inicia el mdulo `World`, `Fps` recibe la frecuencia de 
 * actualizacin por defecto. Si se llama a `fps_set_framerate` se
 * puede alterar la velocidad general del juego.
 *
 * La velocidad constante se logra de dos maneras, por un lado la 
 * funcin `fps_synchronize` puede detener el programa (si el equipo es 
 * muy rpido) o retornar un valor mayor a 0 (si el equipo es lento). Este 
 * ltimo caso nos permite `saltar` cuadros compenzando la prdida de 
 * velocidad.
 */
typedef struct fps_t
{
	int current_tick;		/*!< Tick actual */
	int last_tick;
	int frequency;			/*!< Frecuencia de actualizacin, 
					  de donde: 1000/frequency = FPS */
	int fps;
	int tick_last_fps_notify;	/*! Valor de Ticks al momento de 
					  informar el rendimiento de ejecucin
					  en cuadros por segundo (FPS) */
	int max_frame_skip;		/*!< Cantidad mxima de saltos 
					  permitida */
	int debug;			/*!< Indica si el juego est en
					  modo depuracin */
} Fps;


Fps * fps_init (int fps_requested, int debug);
float fps_synchronize (Fps * data);
void fps_reset (Fps * data);
void fps_update_display (Fps * data);
void fps_free (Fps * data);
void fps_set_debug_title (Fps * data);

#endif
