/*
 * Volleyball - video game similary to GNU Arcade Volleyball
 * Copyright (C) 2005, 2006 Hugo Ruscitti : hugoruscitti@gmail.com
 * web site: http://www.losersjuegos.com.ar
 * 
 * This file is part of Volleyball.
 *
 * Volleyball is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Volleyball is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 */

#include "game.h"
#include "main_menu.h"

/*!
 * \brief Inicia un partido
 * \param world mdulo principal
 * \param player_1 jugador 1
 * \param player_2 jugador 2
 * \return el mdulo generado 
 */
Game * game_init (World * world, Player * player_1, Player * player_2)
{
	Game * data;

	data = (Game *) malloc (sizeof (Game));

	if (! data)
	{
		util_print_fail_module ("Game");
		exit (1);
	}

	data->world = world;
	data->player_1 = player_1;
	data->player_2 = player_2;
	
	data->status_bar = status_bar_init (data->world);
	data->ball = ball_init (data, data->world->options->debug);

	player_init_game (data->player_1, data->ball, 0, 0, 320 - 10);
	player_init_game (data->player_2, data->ball, 1, 320 + 10, 640);

	game_draw_background (data);

	return data;
}


/*!
 * \brief Imprime el fondo de pantalla
 * \param data mdulo principal
 */ 
void game_draw_background (Game * data)
{
	SDL_Surface * background;

	background = util_load_image (DATADIR "/stage1.png", FALSE);

	if (background)
	{
		if (data->world->options->debug)
		{
			Uint32 c = SDL_MapRGB (background->format, 255, 90, 0);
			
			util_draw_circle (background, c, PILLAR_X, PILLAR_Y, 
					PILLAR_RATIO);
		}
		
		display_set_background (data->world->display, background);
		SDL_FreeSurface (background);
	}
}


/*!
 * \brief Actualizacin Lgica
 * \param data mdulo principal
 */ 
void game_update (Game * data)
{
	status_bar_update (data->status_bar);
	player_update (data->player_1);
	player_update (data->player_2);
	ball_update (data->ball);

	if (control_query (data->world->control, QUIT))
	{
		Main_menu * menu;

		menu = main_menu_init (data->world, 0);
	
		world_change_scene (data->world, menu, main_menu_update, 
				main_menu_draw, main_menu_free);
	}
}


/*!
 * \brief Actualizacin grfica
 * \param data mdulo principal
 */ 
void game_draw (Game * data)
{
	player_draw (data->player_1, data->world->display);
	player_draw (data->player_2, data->world->display);
	ball_draw (data->ball, data->world->display);
	status_bar_draw (data->status_bar, data->world->display);
}


/*!
 * \brief termina la partida
 * \param data mdulo principal
 */
void game_free (Game * data)
{
	status_bar_free (data->status_bar);
	ball_free (data->ball);
	free (data);
}
