/*
 * Volleyball - video game similary to GNU Arcade Volleyball
 * Copyright (C) 2005, 2006 Hugo Ruscitti : hugoruscitti@gmail.com
 * web site: http://www.loosersjuegos.com.ar
 * 
 * This file is part of Volleyball.
 *
 * Volleyball is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Volleyball is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 */

#ifndef _ITEM_H
#define _ITEM_H

#include "display.h"
#include "font.h"


enum item_type 
{
	ITEM_NORMAL_TYPE,	/*!< Opcin normal */
	ITEM_PROGRESS_TYPE	/*!< Opcin con selecton de deplazamiento */
};

/*!
 * \file
 */

/*!
 * \brief Representa una opcin dentro del men
 */
typedef struct item_t
{
	char title [256];
	enum item_type type;
	Font * font;
	Display * display;
	int enabled;
	int selected;
	
	int x;
	int y;
	
	int max_progress;	/*!< Solo vlido si es un item_progress */
	int progress_value;	/*!< Solo vlido si es un item_progress */
	void * module_receiver;	/*!< Receptor de cambios en progress_value */
	void (* function_to_notify) (); /*< Notifica el cambio de progress_value a module_receiver */
} Item;

Item * item_new (char * title, int x, int y, Font * font, Display * display);
Item * item_progress_new (char * title, int x, int y, Font * font, 
		Display * display, int max_progress, int initial_progress);
void item_draw (Item * data);
void item_enter (Item * data);
void item_disable (Item * data);
void item_enable (Item * data);
int item_is_enabled (Item * data);
void item_leave (Item * data);
int item_get_y (Item * data);
void item_free (void * data);
void item_progress_add (Item * data);
void item_progress_subtract (Item * data);
void item_progress_draw_value (Item * data);
enum type item_get_font_type (Item * data);

void item_on_change_progress_value (Item * data,
		void (* function) (void * module, int value), void * module);

#endif
