/*
 * Volleyball - video game similary to GNU Arcade Volleyball
 * Copyright (C) 2005, 2006 Hugo Ruscitti : hugoruscitti@gmail.com
 * web site: http://www.loosersjuegos.com.ar
 * 
 * This file is part of Volleyball.
 *
 * Volleyball is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Volleyball is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 */

#include "main_menu.h"
#include "select.h"
#include "select_vs.h"
#include "select_demo.h"
#include "about.h"
#include "option_menu.h"


/*!
 * \brief Inicia la escena, en caso de error termina el programa
 * \param world mdulo World
 * \return el mdulo creado
 */
Main_menu * main_menu_init (World * world, int initial_option)
{
	Main_menu * data;

	data = (Main_menu *) malloc (sizeof (Main_menu));

	if (!data)
	{
		util_print_fail_module ("Main_menu");
		exit (1);
	}

	data->world = world;
	data->menu = menu_init (world);

	menu_add_item (data->menu, _("New game: single mode"));
	menu_add_item (data->menu, _("New game: vs mode"));
	menu_add_item (data->menu, _("New game: demo mode"));
	menu_add_item (data->menu, _("Options"));
	menu_add_item (data->menu, _("About this game"));
	menu_add_item (data->menu, _("Quit"));

	menu_set_initial_option (data->menu, initial_option);
	
	main_menu_draw_background (data);

	return data;
}


/*!
 * \brief Imprime el fondo de pantalla
 * \param data mdulo principal
 */
void main_menu_draw_background (Main_menu * data)
{
	SDL_Surface * background;
	SDL_Surface * title;

	background = util_load_image (DATADIR "/main_menu.png", FALSE);
	
	
	if (background)
	{
		title = util_load_image (DATADIR "/title.png", TRUE);

		if (title)
		{
			SDL_Rect dst = {dst.x = 320 - title->w / 2, 25, 0, 0};
			
			SDL_BlitSurface (title, NULL, background, & dst);
			SDL_FreeSurface (title);
		}
		
		display_set_background (data->world->display, background);
		SDL_FreeSurface (background);
	}

	
}

/*!
 * \brief Actualizacin lgica
 * \param data mdulo principal
 */
void main_menu_update (Main_menu * data)
{
	int option;

	option = menu_update (data->menu);

	switch (option)
	{
		case 0:
			{
				Select * select;
				select = select_init (data->world);

				world_change_scene (data->world, select, 
					select_update, select_draw, 
					select_free);
			}
			break;
			
		case 1:
			{
				Select_vs * select_vs;
				select_vs = select_vs_init (data->world);

				world_change_scene (data->world, select_vs, 
					select_vs_update, select_vs_draw, 
					select_vs_free);
			}
			break;

		case 2:
			{
				Select_demo * select_demo;
				select_demo = select_demo_init (data->world);

				world_change_scene (data->world, select_demo, 
					select_demo_update, select_demo_draw, 
					select_demo_free);
			}
			break;


			
		case 3:
			{
				Option_menu * option;
				option = option_menu_init (data->world);

				world_change_scene (data->world, option,
					option_menu_update, option_menu_draw,
					option_menu_free);	
			}
			break;
			
		case 4:
			{
				About * about;
				about = about_init (data->world);

				world_change_scene (data->world, about, 
					about_update, about_draw, 
					about_free);
			}
			break;

		case 5:
			world_quit (data->world);
			break;

		default:
			break;
	}
}


/*!
 * \brief Actualizacin grfica
 * \param data mdulo principal
 */
void main_menu_draw (Main_menu * data)
{
	menu_draw (data->menu);
}


/*!
 * \brief Termina la escena
 * \param data mdulo principal
 */
void main_menu_free (Main_menu * data)
{
	menu_free (data->menu);
	free (data);
}

