/*
 * Volleyball - video game similary to GNU Arcade Volleyball
 * Copyright (C) 2005, 2006 Hugo Ruscitti : hugoruscitti@gmail.com
 * web site: http://www.losersjuegos.com.ar
 * 
 * This file is part of Volleyball.
 *
 * Volleyball is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Volleyball is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 */

#include "memo.h"

/*!
 * \brief inicia el mdulo
 * \param world mdulo gestor del juego
 * \param text texto a mostrar en pantalla
 */
Memo * memo_init (World * world, const char * text)
{
	Memo * data;

	data = (Memo *) malloc (sizeof (Memo));

	if (! data)
	{
		util_print_fail_module ("Memo");
		exit (1);
	}
	
	data->text = calloc (strlen (text) + 1, sizeof (char));

	if (! data->text)
	{
		util_print_fail_module ("Memo");
		exit (1);
	}

	strcpy (data->text, text);
	
	data->world = world;

	return data;
}


/*!
 * \brief Imprime el texto en pantalla
 * \param data mdulo principal
 */
void memo_draw (Memo * data)
{
	Font * font = data->world->font;
	Display * display = data->world->display;
	int i;
	int y = 10;
	int x = 10;

	for (i = 0; data->text [i]; i ++)
	{
		if (data->text [i] == '\n')
		{
			y += font_get_h (font);
			x = 10;
		}
		else
		{
			x += font_print_char (font, display, x, y, FALSE, 
					data->text [i]);
		}
	}
}


/*!
 * \brief Actualizacin lgica
 * \param data mdulo principal
 */
void memo_update (Memo * data)
{
}


/*!
 * \brief Libera los recursos solicitados por el campo de texto
 * \param data mdulo principal
 */
void memo_free (Memo * data)
{
	free (data->text);
}

