/*
 * Volleyball - video game similary to GNU Arcade Volleyball
 * Copyright (C) 2005, 2006 Hugo Ruscitti : hugoruscitti@gmail.com
 * web site: http://www.loosersjuegos.com.ar
 * 
 * This file is part of Volleyball.
 *
 * Volleyball is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Volleyball is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 */

#ifndef _MENU_H
#define _MENU_H

#include "font.h"
#include "world.h"
#include "item.h"
#include "pointer.h"

/*!
 * \brief Menu con mltiples opciones
 *
 * Para utilizar este mdulo deber llamar a `menu_add_item` indicando 
 * cuales sern las opciones disponibles y luego, con el retorno de 
 * `menu_update`, conocer que opcin seleccion el usuario (ver mdulo 
 * `main_menu` como ejemplo)
 */
typedef struct menu_t
{
	int option;
	int start_y;
	World * world;
	Item * items [10];
	int items_n;
	Pointer * pointer; 
} Menu;

/*!
 * \file
 */

Menu * menu_init (World * world);
void menu_draw (Menu * data);
int menu_update (Menu * data);
void menu_change_option (Menu * data, int delta);
void menu_add_item (Menu * data, char * title);
void menu_add_progress_item (Menu * data, char * title, int max_progress, 
		int initial_progress);
void menu_internal_add_item (Menu * data);
void menu_disable_item (Menu * data, int index);
void menu_enable_item (Menu * data, int index);
void menu_free (Menu * data);
void menu_set_initial_option (Menu * data, int initial_option);

#endif
