/*
 * Volleyball - video game similary to GNU Arcade Volleyball
 * Copyright (C) 2005, 2006 Hugo Ruscitti : hugoruscitti@gmail.com
 * web site: http://www.loosersjuegos.com.ar
 * 
 * This file is part of Volleyball.
 *
 * Volleyball is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Volleyball is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 */

#include "node.h"

/*!
 * \brief Aade un nodo a la lista enlazada
 * \param list lista original
 * \param data puntero al nuevo elemento
 * \return una nueva lista de elementos
 */
Node * node_add (Node * list, void * data)
{
	Node * new;

	new = (Node *) malloc (sizeof (Node));

	if (! new)
	{
		printf (_("Error: Memory Fail in '%s' function\n"), 
					"node_add (malloc)");
		exit (1);
	}

	new->data = data;
	new->next = list;
	
	return new;
}


/*!
 * \brief Libera todos los nodos de la lista enlazada
 * \param list lista enlazada
 */
void node_free_all (Node * list, void (* free_data) (void *))
{
	Node * read;
	Node * last = NULL;

	for (read = list; read; read = read->next)
	{
		if (last)
		{
			free_data (last->data);
			free (last);
		}

		last = read;
	}
}


/*!
 * \brief Permite obtener todos los elementos de la lista
 * \param list para comenzar a recorrer debe utilizar un puntero al primer elemento de la lista, para avanzar hasta el final tiene que utilizar NULL
 * \return el contenido del puntero actual o NULL si termina de recorrer la lista
 */
void * node_iterator_next (Node * list)
{
	static Node * iterator;
	
	if (list)
	{
		iterator = list;
		return NULL;
	}
	else
	{
		Node * actual = iterator;

		if (iterator)
		{
			iterator = iterator->next;
			return actual->data;
		}
		else
		{
			return NULL;
		}
	}
}

/*!
 * \brief Informa la cantidad de nodos que tiene una lista
 * \param list primer nodo de la lista
 * \return cantidad de elementos
 */
int node_count (Node * list)
{
	int n;

	for (n = 0; list; list = list->next)
		n ++;

	return n;
}
