/*
 * Volleyball - video game similary to GNU Arcade Volleyball
 * Copyright (C) 2005, 2006 Hugo Ruscitti : hugoruscitti@gmail.com
 * web site: http://www.loosersjuegos.com.ar
 * 
 * This file is part of Volleyball.
 *
 * Volleyball is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Volleyball is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 */

#ifndef _PLAYER_H
#define _PLAYER_H

#include "common.h"
#include "fileoptions.h"
#include "display.h"
#include "player_control.h"
#include "animation.h"

/*! \brief Define la cantidad de atributos que se obtienen desde `info.txt` */
#define MAX_OPTIONS 27

/*!
 * \file
 */

/*!
 * \brief Representa un personaje del juego
 *
 */
typedef struct player_t
{
	struct ball * ball;
	Player_control * control;	/*!< maneja los movimientos */
	Animation * animation;		/*!< maneja los cuadros de animacin */
	
	char nick [256];		/*!< nombre corto */
	char description [256];		/*!< descripcin del personaje */
	char author [256];		/*!< nombre del autor */
	char email [256];		/*!< correo electrnico */
	char web [256];			/*!< url de la web del autor */

	SDL_Surface * image;		/*!< grilla de cuadros */
	SDL_Surface * preview;		/*!< rostro del personaje */

	int debug;
	int x;				/*! posicin horizontal */
	int y;				/*! posicin vertical */
	int actual_dx;			/*! desplazamiento horizontal actual */
	int flip;			/*! espejado (0 derecha, 1 izquierda)*/
	int arena_boundary_left;	/*! limite en su campo de juego */
	int arena_boundary_right;	/*! limite en su campo de juego */
	int initial_jump_speed;		/*! velocidad inicial del salto */
	
	int step;			/*! paso dentro de la animacin */
	int frame;			/*! cuadro actual en la grilla */
	int delay;			/*! pausa entre cuadros de animacin */
	int jump_power;			/*! velocidad inicial de salto */
	int speed;			/*! velocidad horizontal */
	int width;			/*! ancho de colisin con las paredes */

	int columns;			/*! columnas en la grilla completa */
	int hotspot_x;			/*! eje o punto de control */
	int hotspot_y;			/*! eje o punto de control */
	
	int collision_x;		/*! eje de colisin horizontal */
	int collision_y;		/*! eje de colisin vertical */
	int collision_ratio;		/*! radio del crculo de colisin */
	
	void (* state) (struct player_t * data);	/*! estado actual */
} Player;



Player * player_init (char * path, char * file, int debug);
int player_init_examine_files (char * complete_path);
int player_init_load_images (Player * data, char * complete_path);
int player_init_load_attributes (Player * data, char * complete_path);
void player_draw_debug_lines (Player * data);

void player_draw_preview (Player * data, int x, int y, Display * display);
void player_draw (Player * data, Display * display);
void player_free (void * data);

void player_init_game (Player * data, struct ball * ball, int player, 
		int left, int right);

void player_set_position (Player * data, int x, int y, int flip);
void player_set_control (Player * data, Player_control * control);
void player_update (Player * data);
void player_update_animation (Player * data);

void player_change_state (Player * data, void (* init) (Player * data), 
		void (* update) (Player * data));

void player_state_ready (Player * data);
void player_state_select (Player * data);
void player_state_run_left (Player * data);
void player_state_run_right (Player * data);
void player_state_jump (Player * data);

void player_init_ready (Player * data);
void player_init_select (Player * data);
void player_init_run_left (Player * data);
void player_init_run_right (Player * data);
void player_init_jump (Player * data);

void player_set_arena_boudary (Player * data, int left, int right);
void player_move (Player * data, int direction);
int player_collision (Player * data, int x, int y, int ratio);
void player_get_collision_area (Player * data, int * x, int * y, int * ratio);
float player_get_collision_power (Player * data, int dx);
void player_collision_with_ball (Player * data, int dx);

void player_do_run_left (Player * data);
void player_do_run_right (Player * data);
void player_do_jump (Player * data);
void player_do_ready (Player * data);

/* localizadas */
void player_ai_do_run_to_best_place_to_start (Player * data);
void player_ai_do_start_game_jumping (Player * data);
void player_ai_do_waiting_receive (Player * data);
void player_ai_do_waiting_other_player (Player * data);

void player_set_ai_control (Player * data);

#endif
