/*
 * Volleyball - video game similary to GNU Arcade Volleyball
 * Copyright (C) 2005, 2006 Hugo Ruscitti : hugoruscitti@gmail.com
 * web site: http://www.loosersjuegos.com.ar
 * 
 * This file is part of Volleyball.
 *
 * Volleyball is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Volleyball is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 */

#include "player_control.h"

/*!
 * \brief inicia el mdulo
 * \return el control de un personaje
 */
Player_control * player_control_init (Control * control, int player)
{
	Player_control * data;

	data = (Player_control *) malloc (sizeof (Player_control));

	if (! data)
	{
		util_print_fail_module ("Player_control");
		exit (1);
	}

	data->control = control;
	data->player = player;
	data->last_key = -1;

	return data;
}


/*!
 * \brief libera el mdulo de control
 * \param data mdulo principal
 */
void player_control_free (Player_control * data)
{
	free (data);
}

/*!
 * \brief indica si el usuario ha pulsado una tecla
 * \param mdulo principal
 * \param key tecla a consultar
 * \return TRUE en caso afirmativo o FALSE si no se puls esa tecla
 */
int player_control_query (Player_control * data, enum player_key key)
{
	return control_query (data->control, key + 2 + data->player * 5);
}

/*!
 * \brief indica si el usuario ha pulsado una tecla (sin repeticin)
 * \param mdulo principal
 * \param key tecla a consultar
 * \return TRUE en caso afirmativo o FALSE si no se puls esa tecla
 */
int player_control_query_no_repeat (Player_control * data, enum player_key key)
{
	int offset = 2 + data->player * 5;

	if (data->last_key != -1)
	{
		if (control_query (data->control, data->last_key + offset))
			return FALSE;
		else
			data->last_key = -1;
	}

	if (control_query (data->control, key + offset))
	{
		data->last_key = key;
		return TRUE;
	}
	else
		return FALSE;
}
