/*
 * Volleyball - video game similary to GNU Arcade Volleyball
 * Copyright (C) 2005, 2006 Hugo Ruscitti : hugoruscitti@gmail.com
 * web site: http://www.loosersjuegos.com.ar
 * 
 * This file is part of Volleyball.
 *
 * Volleyball is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Volleyball is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 */

#include "pointer.h"

/*!
 * \brief genera el puntero del men
 * \param x posicin horizontal
 * \param y posicin vertical
 * \param end_y posicin vertical que debe alcanzar
 * \param display mdulo que controla la impresin de grficos
 */
Pointer * pointer_new (int x, int y, int end_y, Display * display)
{
	Pointer * data;

	data = (Pointer *) malloc (sizeof (Pointer));

	if (! data)
	{
		util_print_fail_module ("Pointer");
		exit (1);
	}

	data->image = util_load_image (DATADIR "/pointer.png", TRUE);

	if (! data->image)
	{
		util_print_fail_module ("Pointer");
		exit (1);
	}

	
	data->x = x;
	data->y = y;
	data->end_y = y;
	data->display = display;
	data->step = 0;

	return data;
}

/*!
 * \brief actualiza la posicin y animacin del puntero
 * \param data mdulo principal
 */
void pointer_update (Pointer * data)
{
	static int delay = 0;
	
	data->y += (data->end_y - data->y) / 2;

	if (++ delay > 1)
	{
		delay = 0;
	
		data->step ++;

		if (data->step >= 24)
			data->step = 0;
	}
}

/*!
 * \brief imprime el puntero sobre la pantalla
 * \param data mdulo principal
 */
void pointer_draw (Pointer * data)
{
	int x = data->x - 20;
	int y = data->y + 8;

	display_draw (data->display, data->image, data->step, 24, x, y, FALSE);
}

/*!
 * \brief altera la posicin del puntero
 * \param data mdulo principal
 * \param end_y nuevo valor para la posicin vertical
 */
void pointer_change (Pointer * data, int end_y)
{
	data->end_y = end_y;
}

/*!
 * \brief define la posicin vertical del puntero
 * \param data mdulo principal
 * \param y posicin vertical
 */
void pointer_set_y (Pointer * data, int y)
{
	data->y = y;
	data->end_y = y;
}

/*!
 * \brief elimina el mdulo Pointer
 * \param data referencia al mdulo
 */
void pointer_free (Pointer * data)
{
	SDL_FreeSurface (data->image);
	free (data);
}
