/*
 * Volleyball - video game similary to GNU Arcade Volleyball
 * Copyright (C) 2005, 2006 Hugo Ruscitti : hugoruscitti@gmail.com
 * web site: http://www.loosersjuegos.com.ar
 * 
 * This file is part of Volleyball.
 *
 * Volleyball is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Volleyball is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 */

#include "select_vs.h"
#include "select.h"
#include "display.h"
#include "main_menu.h"
#include "player.h"
#include "game.h"

/*!
 * \brief Genera el mdulo de escena `select_vs`
 * \param world mdulo principal del programa
 * \return el mdulo creado, o aborta el programa si ocurre un error
 */
Select_vs * select_vs_init (World * world)
{
	Select_vs * data;
	int max_players;

	data = (Select_vs *) malloc (sizeof (Select_vs));

	if (! data)
	{
		util_print_fail_module ("select_vs");
		exit (1);
	}

	data->vs_mode = TRUE;
	data->world = world;
	select_draw_background ((Select *) data);
	
	max_players = characters_count_players (world->characters);

	data->cursor_1 = cursor_init (world, 0, max_players);
	data->cursor_2 = cursor_init (world, 1, max_players);
	
	return data;
}


/*!
 * \brief Actualizacin lgica de la escena
 * \param data mdulo principal
 */
void select_vs_update (Select_vs * data)
{
	Cursor * c1 = data->cursor_1;
	Cursor * c2 = data->cursor_2;
	
	cursor_update (c1);
	cursor_update (c2);

	if (cursor_selected (c1) && cursor_selected (c2))
	{
		select_vs_init_game (data);
	}
	
	if (control_query (data->world->control, QUIT))
		select_return_to_main ((Select *) data, 1);
}

/*!
 * \brief Actualizacin grafica
 * \param data mdulo principal
 */
void select_vs_draw (Select_vs * data)
{
	select_draw ((Select *) data);
	cursor_draw (data->cursor_2, data->world->display);
}

/*!
 * \brief Elimina el mdulo `select_vs`
 * \param data mdulo principal
 */
void select_vs_free (Select_vs * data)
{
	cursor_free (data->cursor_1);
	cursor_free (data->cursor_2);
	free (data);
}

/*!
 * \brief termina la escena select_vs para iniciar el juego, esta funcin ser 
 *        invocada desde la funcin cursor_select_vs.
 * \param data mdulo principal
 */
void select_vs_init_game (Select_vs * data)
{
	Game * game;
	Player * p1 = cursor_get_player (data->cursor_1);
	Player * p2 = cursor_get_player (data->cursor_2);

	player_set_control (p1, data->world->player_control_1);
	player_set_control (p2, data->world->player_control_2);

	game = game_init (data->world, p1, p2);

	world_change_scene (data->world, game, game_update, game_draw, 
			game_free);
}
