/*
 * Volleyball - video game similary to GNU Arcade Volleyball
 * Copyright (C) 2005, 2006 Hugo Ruscitti : hugoruscitti@gmail.com
 * web site: http://www.losersjuegos.com.ar
 * 
 * This file is part of Volleyball.
 *
 * Volleyball is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Volleyball is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 */

#include "status_bar.h"


/*!
 * \brief Inicia la barra de puntajes y tiempo
 * \param world mdulo gestor del programa
 * \return una referencia a `status_bar`
 */
Status_bar * status_bar_init (World * world)
{
	Status_bar * data;

	data = (Status_bar *) malloc (sizeof (Status_bar));

	if (! data)
	{
		util_print_fail_module ("Status_bar");
		exit (1);
	}

	data->world = world;
	data->score_player_1 = 0;
	data->score_player_2 = 0;
	data->time = 90;

	data->text_score_player_1 = text_init (data->world->font, "0", 20, 
			10, ALIGN_LEFT);

	data->text_score_player_2 = text_init (data->world->font, "0", 620, 
			10, ALIGN_RIGHT);
	
	data->last_tick = SDL_GetTicks ();

	return data;
}


/*!
 * \brief actualizacin lgica
 * \param data mdulo principal
 */
void status_bar_update (Status_bar * data)
{
	int actual_tick = SDL_GetTicks ();

	text_update (data->text_score_player_1);
	text_update (data->text_score_player_2);
	
	if (actual_tick - data->last_tick > 1000)
	{
		if (data->time > 0)
		{
			data->time --;

			if (data->time < 0)
				data->time = 0;
		}

		data->last_tick += 1000;
	}
}


/*!
 * \brief imprime la barra en pantalla
 * \param data mdulo principal
 * \param display mdulo gestor de pantalla
 */
void status_bar_draw (Status_bar * data, Display * display)
{
	text_draw (data->text_score_player_1, display);
	text_draw (data->text_score_player_2, display);

	font_printf_align (data->world->font, display, 320, 10, FALSE, 
			ALIGN_CENTER, "%d", data->time);
}


/*!
 * \brief Libera los recursos solicitados por el mdulo
 * \param data mdulo principal
 */
void status_bar_free (Status_bar * data)
{
	text_free (data->text_score_player_1);
	text_free (data->text_score_player_2);
	free (data);
}

/*!
 * \brief suma puntaje a uno de los dos jugadores
 * \param data mdulo principal
 * \param player jugador que realiz el tanto, admite los valores 0 y 1
 */
void status_bar_goal (Status_bar * data, int player)
{
	char tmp [32];

	if (player)
	{
		data->score_player_2 ++;
		sprintf (tmp, "%d", data->score_player_2);
		text_change_text (data->text_score_player_2, tmp, 15);
	}
	else
	{
		data->score_player_1 ++;
		sprintf (tmp, "%d", data->score_player_1);
		text_change_text (data->text_score_player_1, tmp, 15);
	}
}
