/*
 * Volleyball - video game similary to GNU Arcade Volleyball
 * Copyright (C) 2005, 2006 Hugo Ruscitti : hugoruscitti@gmail.com
 * web site: http://www.losersjuegos.com.ar
 * 
 * This file is part of Volleyball.
 *
 * Volleyball is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Volleyball is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 */

#include "text.h"

/*!
 * \brief Inicia la cadena de textos
 * \param font mdulo fuente a utilizar
 * \param text texto inicial
 * \param x posicin horizontal
 * \param y posicin vertical
 * \param align alineacin
 */
Text * text_init (Font * font, char * text, int x, int y, enum align align)
{
	Text * data;

	data = (Text *) malloc (sizeof (Text));

	if (! data)
	{
		util_print_fail_module ("Text");
		exit (1);
	}

	data->x = x;
	data->y = y;
	data->align = align;
	data->font = font;
	data->step = 0;

	text_change_text (data, text, 0);

	return data;
}

/*!
 * \brief actualizacin lgica
 * \param data mdulo principal
 */
void text_update (Text * data)
{
	if (data->motion != 0.0)
	{
		data->step += 0.3;
		data->visual_y = data->y + sin (data->step) * data->motion;
		data->visual_x = data->x + cos (data->step) * data->motion;
		data->motion -= 0.5;
	}
	else
	{
		data->visual_y = data->y;
		data->visual_x = data->x;
	}
}

/*!
 * \brief muestra los cambios en pantalla
 * \param data mdulo principal
 * \param display mdulo gestor de pantalla
 */
void text_draw (Text * data, Display * display)
{
	enum type type;

	if (data->motion > 10.0)
		type = TYPE_SELECTED;
	else
		type = TYPE_NORMAL;
	
	font_printf_align (data->font, display, data->visual_x, 
			data->visual_y, type, data->align, data->text);
}

/*!
 * \brief cambia la cadena de texto a mostrar
 * \param data mdulo principal
 * \param text nuevo texto
 * \param new_motion movimiento que se aplica al efecturar el cambio
 */
void text_change_text (Text * data, char * text, int new_motion)
{
	data->motion = new_motion;
	strcpy (data->text, text);
}

/*!
 * \brief libera los recursos solicitados
 * \param data mdulo principal
 */
void text_free (Text * data)
{
	free (data);
}

