/*
 * Volleyball - video game similary to GNU Arcade Volleyball
 * Copyright (C) 2005, 2006 Hugo Ruscitti : hugoruscitti@gmail.com
 * web site: http://www.loosersjuegos.com.ar
 * 
 * This file is part of Volleyball.
 *
 * Volleyball is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Volleyball is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 */

#include "common.h"
#include "world.h"
#include "main_menu.h"


/*!
 * \breif programa principal
 * \param argc cantidad de argumentos enviados por el intrprete de ordenes
 * \param argv argumentos de programa
 * \return 1 en caso de fallar la ejecucin del programa
 */
int main (int argc, char * argv [])
{
	World * world;
	Main_menu * menu;
	
	/* gettext support */
	setlocale (LC_ALL, "");
	bindtextdomain (PACKAGE, LOCALEDIR);
	textdomain (PACKAGE);

	util_print_welcome ();
	util_start_rand ();

	world = world_init (argc, argv);

	if (! world)
		return 1;

	menu = main_menu_init (world, 0);
	
	world_change_scene (world, menu, main_menu_update, main_menu_draw, 
			main_menu_free);

	world_main_loop (world);
	world_free (world);
	
	return 0;
}
